@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.072'; # must be numeric, i.e. not 1.07.1
+our $VERSION = '1.073'; # must be numeric, i.e. not 1.07.1
 $VERSION = eval $VERSION;
 
 use strict;
@@ -25,22 +25,22 @@ require Reddit::Client::Message;
 # Constants
 #===============================================================================
 
-use constant DEFAULT_LIMIT      => 25;
+use constant DEFAULT_LIMIT           => 25;
 
-use constant VIEW_HOT           => '';
-use constant VIEW_NEW           => 'new';
-use constant VIEW_CONTROVERSIAL => 'controversial';
-use constant VIEW_TOP           => 'top';
-use constant VIEW_RISING	=> 'rising';
-use constant VIEW_DEFAULT       => VIEW_HOT;
+use constant VIEW_HOT                => '';
+use constant VIEW_NEW                => 'new';
+use constant VIEW_CONTROVERSIAL      => 'controversial';
+use constant VIEW_TOP                => 'top';
+use constant VIEW_RISING	     => 'rising';
+use constant VIEW_DEFAULT            => VIEW_HOT;
 
-use constant VOTE_UP            => 1;
-use constant VOTE_DOWN          => -1;
-use constant VOTE_NONE          => 0;
+use constant VOTE_UP                 => 1;
+use constant VOTE_DOWN               => -1;
+use constant VOTE_NONE               => 0;
 
-use constant SUBMIT_LINK        => 'link';
-use constant SUBMIT_SELF        => 'self';
-use constant SUBMIT_MESSAGE     => 'message';
+use constant SUBMIT_LINK             => 'link';
+use constant SUBMIT_SELF       	     => 'self';
+use constant SUBMIT_MESSAGE          => 'message';
 
 use constant MESSAGES_INBOX	     => 'inbox';
 use constant MESSAGES_UNREAD	     => 'unread';
@@ -50,35 +50,35 @@ use constant MESSAGES_COMMENTREPLIES => 'comments';
 use constant MESSAGES_POSTREPLIES    => 'selfreply';
 use constant MESSAGES_MENTIONS	     => 'mentions';
 
-use constant API_ME             => 0;
-use constant API_INFO           => 1;
-use constant API_SEARCH         => 2;
-use constant API_LOGIN          => 3;
-use constant API_SUBMIT         => 4;
-use constant API_COMMENT        => 5;
-use constant API_VOTE           => 6;
-use constant API_SAVE           => 7;
-use constant API_UNSAVE         => 8;
-use constant API_HIDE           => 9;
-use constant API_UNHIDE         => 10;
-use constant API_SUBREDDITS     => 11;
-use constant API_LINKS_FRONT    => 12;
-use constant API_LINKS_OTHER    => 13;
-use constant API_DEL            => 14;
-use constant API_MESSAGE        => 15;
-use constant API_COMMENTS_FRONT	=> 16;
-use constant API_COMMENTS	=> 17;
-use constant API_MESSAGES	=> 18;
-use constant API_MARK_READ	=> 19;
-use constant API_MARKALL	=> 20;
-use constant API_MY_SUBREDDITS  => 21;
+use constant API_ME                  => 0;
+use constant API_INFO                => 1;
+use constant API_SEARCH              => 2;
+use constant API_LOGIN               => 3;
+use constant API_SUBMIT              => 4;
+use constant API_COMMENT             => 5;
+use constant API_VOTE                => 6;
+use constant API_SAVE                => 7;
+use constant API_UNSAVE              => 8;
+use constant API_HIDE                => 9;
+use constant API_UNHIDE              => 10;
+use constant API_SUBREDDITS          => 11;
+use constant API_LINKS_FRONT         => 12;
+use constant API_LINKS_OTHER         => 13;
+use constant API_DEL                 => 14;
+use constant API_MESSAGE             => 15;
+use constant API_COMMENTS_FRONT	     => 16;
+use constant API_COMMENTS	     => 17;
+use constant API_MESSAGES	     => 18;
+use constant API_MARK_READ	     => 19;
+use constant API_MARKALL	     => 20;
+use constant API_MY_SUBREDDITS       => 21;
 
-use constant SUBREDDITS_HOME    => '';
-use constant SUBREDDITS_MINE    => 'subscriber';
-use constant SUBREDDITS_POPULAR => 'popular';
-use constant SUBREDDITS_NEW     => 'new';
-use constant SUBREDDITS_CONTRIB => 'contributor';
-use constant SUBREDDITS_MOD     => 'moderator';
+use constant SUBREDDITS_HOME         => '';
+use constant SUBREDDITS_MINE         => 'subscriber';
+use constant SUBREDDITS_POPULAR      => 'popular';
+use constant SUBREDDITS_NEW          => 'new';
+use constant SUBREDDITS_CONTRIB      => 'contributor';
+use constant SUBREDDITS_MOD          => 'moderator';
 
 #===============================================================================
 # Parameters
@@ -92,18 +92,18 @@ use constant LINK_URL => 'https://www.reddit.com';
 our $UA               = sprintf 'Reddit::Client/%f', $VERSION;
 
 our @API;
-$API[API_ME            ] = ['GET',  '/api/v1/me'     ];
-$API[API_INFO          ] = ['GET',  '/api/info'      ];
-$API[API_SEARCH        ] = ['GET',  '/reddits/search'];
-$API[API_LOGIN         ] = ['POST', '/api/login/%s'  ];
-$API[API_SUBMIT        ] = ['POST', '/api/submit'    ];
-$API[API_COMMENT       ] = ['POST', '/api/comment'   ];
-$API[API_VOTE          ] = ['POST', '/api/vote'      ];
-$API[API_SAVE          ] = ['POST', '/api/save'      ];
-$API[API_UNSAVE        ] = ['POST', '/api/unsave'    ];
-$API[API_HIDE          ] = ['POST', '/api/hide'      ];
-$API[API_UNHIDE        ] = ['POST', '/api/unhide'    ];
-$API[API_SUBREDDITS    ] = ['GET',  '/subreddits/%s' ];
+$API[API_ME            ] = ['GET',  '/api/v1/me'            ];
+$API[API_INFO          ] = ['GET',  '/api/info'             ];
+$API[API_SEARCH        ] = ['GET',  '/subreddits/search'    ];
+$API[API_LOGIN         ] = ['POST', '/api/login/%s'         ];
+$API[API_SUBMIT        ] = ['POST', '/api/submit'           ];
+$API[API_COMMENT       ] = ['POST', '/api/comment'          ];
+$API[API_VOTE          ] = ['POST', '/api/vote'             ];
+$API[API_SAVE          ] = ['POST', '/api/save'             ];
+$API[API_UNSAVE        ] = ['POST', '/api/unsave'           ];
+$API[API_HIDE          ] = ['POST', '/api/hide'             ];
+$API[API_UNHIDE        ] = ['POST', '/api/unhide'           ];
+$API[API_SUBREDDITS    ] = ['GET',  '/subreddits/%s'        ];
 $API[API_MY_SUBREDDITS ] = ['GET',  '/subreddits/mine/%s'   ];
 $API[API_LINKS_OTHER   ] = ['GET',  '/%s'                   ];
 $API[API_LINKS_FRONT   ] = ['GET',  '/r/%s/%s'              ];
@@ -201,7 +201,7 @@ sub version {
 sub request {
     my ($self, $method, $path, $query, $post_data) = @_;
 
-	if (!$self->{last_token} || $self->{last_token} <= time - 3600) {
+	if (!$self->{last_token} || $self->{last_token} <= time - 3598) {
 		$self->get_token(client_id=>$self->{client_id}, secret=>$self->{secret}, username=>$self->{username}, password=>$self->{password});
 	}
 
@@ -240,7 +240,7 @@ sub get_token {
 
 sub has_token {
 	my $self = shift;
-	return (!$self->{last_token} || $self->{last_token} <= time - 3600) ? 0 : 1;
+	return (!$self->{last_token} || $self->{last_token} <= time - 3598) ? 0 : 1;
 }
 
 sub json_request {
@@ -469,24 +469,33 @@ sub get_permalink {
 }
 
 sub find_subreddits {
-    my ($self, $query) = @_;
-    defined $query || croak 'Expected $query';
-    DEBUG('Search subreddits: %s', $query);
-    my $result = $self->api_json_request(api => API_SEARCH, data => { q => $query });
-    return {
-        map { $_->{data}{display_name} => Reddit::Client::SubReddit->new($self, $_->{data}) }
-            @{$result->{data}{children}}
-    };
+    	my ($self, %param) = @_;
+	#defined $query || croak 'Expected $query';
+	#DEBUG('Search subreddits: %s', $query);
+
+    	my $query  = {};
+	$query->{q} = $param{q} || croak "expected 'query'";
+        $query->{before} = $param{before} if $param{before};
+        $query->{after}  = $param{after}  if $param{after};
+	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
+	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
+
+	# sort
+	$query->{sort} = $param{sort} || 'relevance';
+
+    	my $result = $self->api_json_request(
+		api => API_SEARCH, 
+		data => $query,
+	);
+    	return [
+        	map {Reddit::Client::SubReddit->new($self, $_->{data})} @{$result->{data}{children}}
+    	];
 }
 
 sub fetch_links {
     my ($self, %param) = @_;
     my $subreddit = $param{subreddit} || '';
     my $view      = $param{view}      || VIEW_DEFAULT;
-    #my $limit     = $param{limit}     || DEFAULT_LIMIT;
-    #my $before    = $param{before};
-    #my $after     = $param{after};
-
     #DEBUG('Fetch %d link(s): %s/%s?before=%s&after=%s', $limit, $subreddit, $view, ($before || '-'), ($after || '-'));
 
     	my $query  = {};
@@ -494,7 +503,6 @@ sub fetch_links {
         $query->{after}  = $param{after}  if $param{after};
 	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
 	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
-		
 
     $subreddit = subreddit($subreddit);
 
@@ -1060,16 +1068,10 @@ with an api_type of "json". After the request is complete, parses the
 JSON result and throws and error if one is specified in the result
 contents. Otherwise, returns the json data portion of the result.
 
-=item    authenticate
-
-=item   authorize
-
 =item    get_permalink
 
 =item    get_token
 
-=item    is_logged_in
-
 =item    send_message
 
 =item api_json_request
