@@ -7,7 +7,7 @@ use Carp;
 require Reddit::Client::Thing;
 
 use base   qw/Reddit::Client::Thing/;
-use fields qw/has_mail created modhash created_utc link_karma
+use fields qw/has_mail created modhash created_utc link_karma over_18
               comment_karma is_gold is_mod has_mod_mail/;
 
 1;
@@ -26,6 +26,8 @@ Stores information about the logged in user account.
 
 =head1 AUTHOR
 
+<mailto:earth-tone@ubwg.net>
+
 Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
