@@ -27,8 +27,19 @@ sub replies {
 }
 
 sub reply {
-    my $self = shift;
-    return $self->SUPER::submit_comment(@_);
+    my ($self, $text) = @_;
+	$text || croak "need comment text";	
+	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{parent_id}, text=>$text);
+	return "t1_".$cmtid if $cmtid;
+	return $cmtid;
+    #return $self->SUPER::submit_comment(@_);
+}
+
+sub get_permalink {
+	my $self = shift;
+
+	my $info = $self->{session}->info($self->{link_id});
+	return sprintf "%s%s%s", $self->{session}->LINK_URL, $info->{permalink}, $self->{id};
 }
 
 1;
