@@ -13,6 +13,13 @@ use fields qw/link_flair_text media url link_flair_css_class num_reports
               num_comments clicked saved thumbnail subreddit_id approved_by
               selftext_html created hidden over_18 permalink/;
 
+sub reply {
+    my ($self, $text) = @_;
+	$text || croak "need comment text";	
+	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{name}, text=>$text);
+	return "t1_".$cmtid if $cmtid;
+	return $cmtid;
+}
 sub comments {
     my $self = shift;
     return $self->{session}->get_comments(permalink => $self->{permalink});
