@@ -35,16 +35,6 @@ sub unsave {
     $self->{session}->unsave($self->{name});
 }
 
-sub hide {
-    my $self = shift;
-    $self->{session}->hide($self->{name});
-}
-
-sub unhide {
-    my $self = shift;
-    $self->{session}->unhide($self->{name});
-}
-
 1;
 
 __END__
